BinaryReader class

Constructors

BinaryReader({required Uint8List bytes})
BinaryReader.fromByteData(ByteData data)
factory
BinaryReader.fromFile(String url)
factory

Properties

bytes → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
pos ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(int size) → ByteData?
readFixedLengthString(int length) → String
readFourCC() → String
readInt16() → int
readInt16BigEndian() → int
readInt32() → int
readInt32BigEndian() → int
readInt8() → int
readMidiVariablelength() → int
readUInt16() → int
readUInt32() → int
readUInt8() → int
skip(int size) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited