SampleHeader class

Represents a sample in the SoundFont.

Constructors

SampleHeader({required String name, required int start, required int end, required int startLoop, required int endLoop, required int sampleRate, required int originalPitch, required int pitchCorrection, required int link, required SampleType type})
SampleHeader.defaultSampleHeader()
factory
SampleHeader.fromReader(BinaryReader reader)
factory

Properties

end → int
The end point of the sample in the sample data.
final
endLoop → int
The loop end point of the sample in the sample data.
final
hashCode → int
The hash code for this object.
no setterinherited
final
name → String
The name of the sample.
final
originalPitch → int
The key number of the recorded pitch of the sample.
final
pitchCorrection → int
The pitch correction in cents that should be applied to the sample on playback.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → int
The sample rate of the sample.
final
start → int
The start point of the sample in the sample data.
final
startLoop → int
The loop start point of the sample in the sample data.
final
type → SampleType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
The name of the sample.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

readFromChunk(BinaryReader reader, int size) → List<SampleHeader>